.. _api_reference:

Python API Reference
====================


The Python API Reference provides an overview of all public objects, functions and methods implemented in eodag.

.. toctree::
   :maxdepth: 2

   core
   searchresult
   eoproduct
   utils
   exceptions
   call_graphs
